Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(419)

Unified Diff: chrome/browser/password_manager/native_backend_kwallet_x.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/password_manager/native_backend_kwallet_x.cc
diff --git a/chrome/browser/password_manager/native_backend_kwallet_x.cc b/chrome/browser/password_manager/native_backend_kwallet_x.cc
index b797ad0219c5705b25fc7ab43323e2e8bd5b87d3..ee932cd25c3a7390624e85f1411fdb60da4090e5 100644
--- a/chrome/browser/password_manager/native_backend_kwallet_x.cc
+++ b/chrome/browser/password_manager/native_backend_kwallet_x.cc
@@ -272,9 +272,9 @@ void SerializeValue(const std::vector<std::unique_ptr<PasswordForm>>& forms,
pickle->WriteInt64(form->date_synced.ToInternalValue());
pickle->WriteString16(form->display_name);
pickle->WriteString(form->icon_url.spec());
// We serialize unique origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310
- pickle->WriteString(form->federation_origin.unique()
+ pickle->WriteString(form->federation_origin.opaque()
? std::string()
: form->federation_origin.Serialize());
pickle->WriteBool(form->skip_zero_click);
@@ -272,9 +272,9 @@ void SerializeValue(const std::vector<std::unique_ptr<PasswordForm>>& forms,
pickle->WriteString16(form->display_name);
pickle->WriteString(form->icon_url.spec());
- // We serialize unique origins as "", in order to make other systems that
+ // We serialize opaque origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310

Powered by Google App Engine
This is Rietveld 408576698